@@ -21,14 +21,9 @@ using namespace NName;
 #include "myPrivate.h"
 #include "Windows/Synchronization.h"
 
-#include <unistd.h> // rmdir
 #include <errno.h>
 
-#ifdef _WIN32
-#include <direct.h> // mkdir
-#else
-#include <sys/stat.h> // mkdir
-#endif // _WIN32
+#include <glib/gstdio.h>
 #include <sys/types.h>
 #include <fcntl.h>
 
@@ -191,10 +186,10 @@ static BOOL CopyFile(const char *src,const char *dst)
 #endif
 
   // printf("##DBG CopyFile(%s,%s)\n",src,dst);
-  int fout = open(dst,O_CREAT | O_WRONLY | O_EXCL | flags, 0600);
+  int fout = g_open(dst,O_CREAT | O_WRONLY | O_EXCL | flags, 0600);
   if (fout != -1)
   {
-    int fin = open(src,O_RDONLY | flags , 0600);
+    int fin = g_open(src,O_RDONLY | flags , 0600);
     if (fin != -1)
     {
       ret = copy_fd(fin,fout);
@@ -234,7 +229,7 @@ bool SetDirTime(CFSTR fileName, const FILETIME * /* cTime */ , const FILETIME *a
   struct utimbuf buf;
 
   struct stat    oldbuf;
-  int ret = stat(unix_filename,&oldbuf);
+  int ret = g_stat(unix_filename,&oldbuf);
   if (ret == 0) {
     buf.actime  = oldbuf.st_atime;
     buf.modtime = oldbuf.st_mtime;
@@ -264,7 +259,7 @@ bool SetDirTime(CFSTR fileName, const FILETIME * /* cTime */ , const FILETIME *a
     buf.modtime = dw;
   }
 
-  /* ret = */ utime(unix_filename, &buf);
+  /* ret = */ g_utime(unix_filename, &buf);
 
   return true;
 }
@@ -287,13 +282,13 @@ bool GetLongPaths(CFSTR s1, CFSTR s2, UString &d1, UString &d2)
 #ifndef _LIB_FOR_CHERRYTREE
 static int convert_to_symlink(const char * name) {
   TRACEN(printf("LINK(%s)\n",name))
-  FILE *file = fopen(name,"rb");
+  FILE *file = g_fopen(name,"rb");
   if (file) {
     char buf[MAX_PATHNAME_LEN+1];
     char * ret = fgets(buf,sizeof(buf)-1,file);
     fclose(file);
     if (ret) {
-      int ir = unlink(name);
+      int ir = g_unlink(name);
       if (ir == 0) {
         ir = symlink(buf,name);
         TRACEN(printf("TO(%s)\n",buf))
@@ -319,14 +314,14 @@ bool SetFileAttrib(CFSTR fileName, DWORD fileAttributes,CObjectVector<CDelayedSy
   struct stat stat_info;
 #ifdef ENV_HAVE_LSTAT
   if (global_use_lstat) {
-    if(lstat(name,&stat_info)!=0) {
+    if(g_lstat(name,&stat_info)!=0) {
       TRACEN((printf("SetFileAttrib(%s,%d) : false-2-1\n",(const char *)name,fileAttributes)))
       return false;
     }
   } else
 #endif
   {
-    if(stat(name,&stat_info)!=0) {
+    if(g_stat(name,&stat_info)!=0) {
       TRACEN((printf("SetFileAttrib(%s,%d) : false-2-2\n",(const char *)name,fileAttributes)))
       return false;
     }
@@ -346,12 +341,12 @@ bool SetFileAttrib(CFSTR fileName, DWORD fileAttributes,CObjectVector<CDelayedSy
 #endif
      if (S_ISREG(stat_info.st_mode)) {
        TRACEN((printf("##DBG chmod-2(%s,%o)\n",(const char *)name,(unsigned)stat_info.st_mode & gbl_umask.mask)))
-       chmod(name,stat_info.st_mode & gbl_umask.mask);
+       g_chmod(name,stat_info.st_mode & gbl_umask.mask);
      } else if (S_ISDIR(stat_info.st_mode)) {
        // user/7za must be able to create files in this directory
        stat_info.st_mode |= (S_IRUSR | S_IWUSR | S_IXUSR);
        TRACEN((printf("##DBG chmod-3(%s,%o)\n",(const char *)name,(unsigned)stat_info.st_mode & gbl_umask.mask)))
-       chmod(name,stat_info.st_mode & gbl_umask.mask);
+       g_chmod(name,stat_info.st_mode & gbl_umask.mask);
      }
 #ifdef ENV_HAVE_LSTAT
   } else if (!S_ISLNK(stat_info.st_mode)) {
@@ -364,11 +359,11 @@ bool SetFileAttrib(CFSTR fileName, DWORD fileAttributes,CObjectVector<CDelayedSy
     if( S_ISDIR(stat_info.st_mode)) {
        /* Remark : FILE_ATTRIBUTE_READONLY ignored for directory. */
        TRACEN((printf("##DBG chmod-4(%s,%o)\n",(const char *)name,(unsigned)stat_info.st_mode & gbl_umask.mask)))
-       chmod(name,stat_info.st_mode & gbl_umask.mask);
+       g_chmod(name,stat_info.st_mode & gbl_umask.mask);
     } else {
        if (fileAttributes & FILE_ATTRIBUTE_READONLY) stat_info.st_mode &= ~0222; /* octal!, clear write permission bits */
        TRACEN((printf("##DBG chmod-5(%s,%o)\n",(const char *)name,(unsigned)stat_info.st_mode & gbl_umask.mask)))
-       chmod(name,stat_info.st_mode & gbl_umask.mask);
+       g_chmod(name,stat_info.st_mode & gbl_umask.mask);
     }
   }
   TRACEN((printf("SetFileAttrib(%s,%d) : true\n",(const char *)name,fileAttributes)))
@@ -386,7 +381,7 @@ bool RemoveDir(CFSTR path)
   AString name = nameWindowToUnix2(path);
   TRACEN((printf("RemoveDirectoryA(%s)\n",(const char *)name)))
 
-  if (rmdir( (const char *)name ) != 0) {
+  if (g_rmdir ( (const char *)name ) != 0) {
     return FALSE;
   }
   return TRUE;
@@ -404,7 +399,7 @@ bool MyMoveFile(CFSTR existFileName, CFSTR newFileName)
 
   TRACEN((printf("MyMoveFile(%s,%s)\n",(const char *)src,(const char *)dst)))
 
-  int ret = rename(src,dst);
+  int ret = g_rename(src,dst);
   if (ret != 0)
   {
 #ifndef _LIB_FOR_CHERRYTREE
@@ -414,13 +409,13 @@ bool MyMoveFile(CFSTR existFileName, CFSTR newFileName)
       if (bret == FALSE) return false;
 
       struct stat info_file;
-      ret = stat(src,&info_file);
+      ret = g_stat(src,&info_file);
       if (ret == 0) {
     TRACEN((printf("##DBG chmod-1(%s,%o)\n",(const char *)dst,(unsigned)info_file.st_mode & gbl_umask.mask)))
-        ret = chmod(dst,info_file.st_mode & gbl_umask.mask);
+        ret = g_chmod(dst,info_file.st_mode & gbl_umask.mask);
       }
       if (ret == 0) {
-         ret = unlink(src);
+         ret = g_unlink(src);
       }
       if (ret == 0) return true;
     }
@@ -443,11 +438,7 @@ bool CreateDir(CFSTR path)
   const char * name = nameWindowToUnix(path);
 #endif
   bool bret = false;
-#ifdef _WIN32
-  if (mkdir(name) == 0) bret = true;
-#else
-  if (mkdir( name, 0700 ) == 0) bret = true;
-#endif // _WIN32
+  if (g_mkdir( name, 0700 ) == 0) bret = true;
   TRACEN((printf("CreateDir(%s)=%d\n",(const char *)name,(int)bret)))
   return bret;
 }
@@ -509,7 +500,7 @@ bool DeleteFileAlways(CFSTR name)
    const char * unixname = nameWindowToUnix(name);
 #endif
    bool bret = false;
-   if (remove(unixname) == 0) bret = true;
+   if (g_remove(unixname) == 0) bret = true;
    TRACEN((printf("DeleteFileAlways(%s)=%d\n",(const char *)unixname,(int)bret)))
    return bret;
 }
@@ -603,7 +594,7 @@ bool SetCurrentDir(CFSTR path)
 {
    AString apath = UnicodeStringToMultiByte(path);
 
-   return chdir((const char*)apath) == 0;
+   return g_chdir((const char*)apath) == 0;
 }
 
 bool GetCurrentDir(FString &path)
@@ -780,7 +771,7 @@ CDelayedSymLink::CDelayedSymLink(const char * source)
 {
   struct stat st;
 
-  if (lstat(_source, &st) == 0) {
+  if (g_lstat(_source, &st) == 0) {
     _dev = st.st_dev;
     _ino = st.st_ino;
   } else {
@@ -796,7 +787,7 @@ bool CDelayedSymLink::Create()
     errno = EPERM;
     return false;
   }
-  if (lstat(_source, &st) != 0)
+  if (g_lstat(_source, &st) != 0)
     return false;
   if (_dev != st.st_dev || _ino != st.st_ino) {
     // Placeholder file has been overwritten or moved by another
