@@ -1,7 +1,7 @@
 /*
  * ct_actions_file.cc
  *
- * Copyright 2009-2024
+ * Copyright 2009-2025
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -60,7 +60,7 @@ void CtActions::file_save_as()
     }
     CtDialogs::CtStorageSelectArgs storageSelArgs{};
     storageSelArgs.showAutosaveOptions = true;
-    const fs::path currDocFilepath = _pCtMainWin->get_ct_storage()->get_file_path();
+    const fs::path& currDocFilepath = _pCtMainWin->get_ct_storage()->get_file_path();
     if (not currDocFilepath.empty()) {
         storageSelArgs.ctDocType = fs::get_doc_type_from_file_ext(currDocFilepath);
         storageSelArgs.ctDocEncrypt = fs::get_doc_encrypt_from_file_ext(currDocFilepath);
@@ -103,12 +103,12 @@ void CtActions::file_save_as()
             if (CtDocType::MultiFile != storageSelArgs.ctDocType or
                 fs::get_dir_entries(filepath).size())
             {
-                message = str::format(_("A folder '%s' already exists in '%s'.\n<b>Do you want to remove it?</b>"),
+                message = str::format(_("A folder '%s' already exists in '%s'.\n<b>Do you want to replace it?</b>"),
                     str::xml_escape(Glib::path_get_basename(filepath)), str::xml_escape(Glib::path_get_dirname(filepath)));
             }
         }
         else {
-            message = str::format(_("A file '%s' already exists in '%s'.\n<b>Do you want to remove it?</b>"),
+            message = str::format(_("A file '%s' already exists in '%s'.\n<b>Do you want to replace it?</b>"),
                 str::xml_escape(Glib::path_get_basename(filepath)), str::xml_escape(Glib::path_get_dirname(filepath)));
         }
         if (message.size()) {
@@ -228,6 +228,7 @@ void CtActions::preferences_import()
     _pCtConfig->latexSizeDpi = ctConfigImported.latexSizeDpi;
     _pCtConfig->embfileIconSize = ctConfigImported.embfileIconSize;
     _pCtConfig->embfileShowFileName = ctConfigImported.embfileShowFileName;
+    _pCtConfig->embfileMFNameOnDisk = ctConfigImported.embfileMFNameOnDisk;
     _pCtConfig->embfileMaxSize = ctConfigImported.embfileMaxSize;
     _pCtConfig->lineWrapping = ctConfigImported.lineWrapping;
     _pCtConfig->autoSmartQuotes = ctConfigImported.autoSmartQuotes;
