@@ -1,7 +1,7 @@
 /*
  * ct_actions_others.cc
  *
- * Copyright 2009-2024
+ * Copyright 2009-2025
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -68,7 +68,7 @@ void CtActions::link_dismiss()
     if (not _is_curr_node_not_read_only_or_error()) return;
     _link_right_click_pre_action();
     if (not _link_check_around_cursor().empty()) {
-        remove_text_formatting();
+        _remove_text_formatting(true/*dismiss_link*/);
     }
 }
 
@@ -146,11 +146,27 @@ void CtActions::embfile_save()
     if (filepath.empty()) return;
 
     _pCtConfig->pickDirFile = Glib::path_get_dirname(filepath);
+
+    if (curr_file_anchor->get_raw_blob().empty()) {
+        const fs::path& embfilePathLast = curr_file_anchor->get_pathLastMultiFile();
+        if (fs::exists(embfilePathLast) and fs::copy_file(embfilePathLast, filepath.c_str())) {
+            return;
+        }
+    }
+
     g_file_set_contents(filepath.c_str(), curr_file_anchor->get_raw_blob().c_str(), (gssize)curr_file_anchor->get_raw_blob().size(), nullptr);
 }
 
 void CtActions::embfile_open()
 {
+    if (curr_file_anchor->get_raw_blob().empty()) {
+        const fs::path& embfilePathLast = curr_file_anchor->get_pathLastMultiFile();
+        if (fs::exists(embfilePathLast)) {
+            fs::open_filepath(embfilePathLast, false/*open_folder_if_file_not_exists*/, _pCtConfig);
+            return;
+        }
+    }
+
     const size_t open_id = curr_file_anchor->get_unique_id();
     auto mapIter = _embfiles_opened.find(open_id);
     fs::path tmp_filepath;
@@ -700,6 +716,40 @@ void CtActions::table_column_add()
     _pCtMainWin->update_window_save_needed(CtSaveNeededUpdType::nbuf, true/*new_machine_state*/);
 }
 
+void CtActions::table_column_cut()
+{
+    if (not _is_there_anch_widg_selection_or_error('t')) return;
+    if (not _is_curr_node_not_read_only_or_error()) return;
+    table_column_copy();
+    table_column_delete();
+}
+
+void CtActions::table_column_copy()
+{
+    if (not _is_there_anch_widg_selection_or_error('t')) return;
+    auto table_state = std::dynamic_pointer_cast<CtAnchoredWidgetState_TableCommon>(curr_table_anchor->get_state());
+    std::vector<std::vector<Glib::ustring>> new_rows;
+    const size_t num_rows = curr_table_anchor->get_num_rows();
+    const size_t curr_col = curr_table_anchor->current_column();
+    for (size_t r = 0u; r < num_rows; ++r) {
+        new_rows.push_back(std::vector<Glib::ustring>{});
+        new_rows.back().push_back(table_state->rows.at(r).at(curr_col));
+    }
+    table_state->rows = std::move(new_rows);
+    auto new_table = dynamic_cast<CtTableCommon*>(table_state->to_widget(_pCtMainWin));
+    CtClipboard{_pCtMainWin}.table_column_to_clipboard(new_table);
+    delete new_table;
+}
+
+void CtActions::table_column_paste()
+{
+    if (not _is_there_anch_widg_selection_or_error('t')) return;
+    if (not _is_curr_node_not_read_only_or_error()) return;
+    curr_table_anchor->exit_cell_edit();
+    CtClipboard{_pCtMainWin}.table_column_paste(curr_table_anchor);
+    curr_table_anchor->grab_focus();
+}
+
 void CtActions::table_column_delete()
 {
     if (not _is_there_anch_widg_selection_or_error('t')) return;
@@ -765,7 +815,7 @@ void CtActions::table_row_copy()
     // remove rows after current
     while (table_state->rows.size() > curr_table_anchor->current_row() + 1)
         table_state->rows.pop_back();
-    // remove rows between current and header
+    // remove rows before current but after header
     while (table_state->rows.size() > 2)
         table_state->rows.erase(table_state->rows.begin() + 1);
     auto new_table = dynamic_cast<CtTableCommon*>(table_state->to_widget(_pCtMainWin));
