@@ -1,7 +1,7 @@
 /*
  * ct_config.h
  *
- * Copyright 2009-2024
+ * Copyright 2009-2025
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -123,6 +123,7 @@ public:
     int                                         latexSizeDpi{140};
     int                                         embfileIconSize{48};
     bool                                        embfileShowFileName{true};
+    bool                                        embfileMFNameOnDisk{false};
     int                                         embfileMaxSize{10};
     bool                                        lineWrapping{true};
     bool                                        autoSmartQuotes{true};
@@ -146,7 +147,7 @@ public:
     bool                                        ptHighlMatchBra{true};
     int                                         spaceAroundLines{0};
     int                                         relativeWrappedSpace{50};
-    Glib::ustring                               hRule{"~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~"};
+    Glib::ustring                               hRule{CtConst::HORIZONTAL_RULE_DEFAULT};
     CtStringSplittable                          specialChars{CtConst::SPECIAL_CHARS_DEFAULT};
     Glib::ustring                               lastSpecialChar{};
     CtStringSplittable                          selwordChars{CtConst::SELWORD_CHARS_DEFAULT};
