@@ -70,6 +70,7 @@ const inline static gchar* VTE_SHELL_DEFAULT        {"/bin/bash"};
 const inline static gchar* STYLE_SCHEME_LIGHT       {"classic"};
 const inline static gchar* STYLE_SCHEME_DARK        {"cobalt"};
 const inline static gchar* TIMESTAMP_FORMAT_DEFAULT {"%Y/%m/%d - %H:%M"};
+const inline static gchar* HORIZONTAL_RULE_DEFAULT  {"~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~"};
 const inline static gchar* FONT_RT_DEFAULT          {"Sans 11"};
 const inline static gchar* FONT_PT_DEFAULT          {"Sans 11"};
 const inline static gchar* FONT_TREE_DEFAULT        {"Sans 10"};
@@ -87,7 +88,7 @@ const inline static Glib::ustring SPECIAL_CHAR_ARROW_DOUBLE2 {"⇔"};
 const inline static Glib::ustring SPECIAL_CHAR_COPYRIGHT     {"©"};
 const inline static Glib::ustring SPECIAL_CHAR_UNREGISTERED_TRADEMARK {"™"};
 const inline static Glib::ustring SPECIAL_CHAR_REGISTERED_TRADEMARK   {"®"};
-const inline static Glib::ustring SELWORD_CHARS_DEFAULT      {".-@"};
+const inline static Glib::ustring SELWORD_CHARS_DEFAULT      {"_.-@"};
 const inline static Glib::ustring CHARS_LISTBUL_DEFAULT      {"•◇▪-→⇒"};
 const inline static Glib::ustring CHARS_TOC_DEFAULT          {"▸•◇▪"};
 const inline static Glib::ustring CHARS_TODO_DEFAULT         {"☐☑☒"};
