@@ -1,7 +1,7 @@
 /*
  * ct_misc_utils.cc
  *
- * Copyright 2009-2024
+ * Copyright 2009-2025
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -105,10 +105,11 @@ std::string CtCSV::table_to_csv(const CtStringTable& table)
 {
     std::string ret_str;
     for (const auto& row : table) {
-        for (const auto& cell : row) {
-            ret_str += fmt::format("\"{}\"", str::replace(cell, std::string{"\""}, std::string{"\\\""}));
+        const size_t numCols = row.size();
+        for (size_t i = 0u; i < numCols; ++i) {
+            ret_str += fmt::format("\"{}\"", str::replace(row.at(i), std::string{"\""}, std::string{"\\\""}));
 
-            if (cell != row.back()) ret_str += ",";
+            if (i < (numCols - 1u)) ret_str += ",";
         }
         ret_str += "\n";
     }
@@ -434,7 +435,10 @@ bool CtTextIterUtil::startswith(Gtk::TextIter text_iter, const gchar* pChar)
 
 bool str::startswith_url(const gchar* pChar)
 {
-    // look for alpha://anything
+    // look for mailto:anything or alpha://anything
+    if (g_str_has_prefix(pChar, "mailto:")) {
+        return true;
+    }
     int curr_state{0};
     while (true) {
         gunichar curr_char = g_utf8_get_char(pChar);
@@ -465,7 +469,10 @@ bool str::startswith_url(const gchar* pChar)
 
 bool CtTextIterUtil::startswith_url(Gtk::TextIter text_iter)
 {
-    // look for alpha://anything
+    // look for mailto:anything or alpha://anything
+    if (CtTextIterUtil::startswith(text_iter, "mailto:")) {
+        return true;
+    }
     int curr_state{0};
     while (true) {
         const gunichar curr_char = text_iter.get_char();
@@ -806,6 +813,15 @@ int CtStrUtil::is_header_anchor_name(const Glib::ustring& anchorName)
     return 0;
 }
 
+bool CtStrUtil::is_256sum(const char* in_string)
+{
+    if (64 == strlen(in_string)) {
+        static Glib::RefPtr<Glib::Regex> pRegExp256sum = Glib::Regex::create("^[0-9a-f]+$");
+        return pRegExp256sum->match(in_string);
+    }
+    return false;
+}
+
 gint64 CtStrUtil::gint64_from_gstring(const gchar* inGstring, bool hexPrefix)
 {
     gint64 retVal;
@@ -962,7 +978,7 @@ Glib::ustring CtStrUtil::get_accelerator_label(const std::string& accelerator)
 
 std::string CtStrUtil::get_internal_link_from_http_url(std::string link_url)
 {
-    if (str::startswith(link_url, "http"))          return "webs " + link_url;
+    if (str::startswith_url(link_url.c_str()))      return "webs " + link_url;
     else if (str::startswith(link_url, "file://"))  return "file " + Glib::Base64::encode(link_url.substr(7));
     else                                            return "webs http://" + link_url;
 }
