@@ -1,7 +1,7 @@
 /*
  * ct_storage_control.cc
  *
- * Copyright 2009-2024
+ * Copyright 2009-2025
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -124,7 +124,7 @@ static const std::string BAD_ARCHIVE{"_BAD_ARC_"};
 {
     // backups with tildas can either be in the same directory where the db is or in a custom backup dir
     // main_backup is always in the same directory of the main db
-    auto get_custom_backup_file_or_dir = [&]()->std::string {
+    auto get_custom_backup_dir = [&]()->std::string {
         // backup path in custom dir: /custom_dir/full_file_path/filename.ext~
         std::string hash_dir = file_or_dir_path;
         for (auto str : {"\\", "/", ":", "?"}) {
@@ -137,20 +137,30 @@ static const std::string BAD_ARCHIVE{"_BAD_ARC_"};
                 spdlog::error("failed to create backup directory: {}", first_backup_dir);
                 return "";
             }
-            return Glib::build_filename(first_backup_dir, CtConst::CHAR_DOT + Glib::path_get_basename(file_or_dir_path)) + CtConst::CHAR_TILDE;
+            return first_backup_dir;
         }
         catch (Glib::Error& ex) {
             spdlog::error("failed to create backup directory: {}, \n{}", first_backup_dir, ex.what().raw());
             return "";
         }
     };
-
+    std::string backup_dirname;
     if (pCtConfig->customBackupDirOn and not pCtConfig->customBackupDir.empty()) {
-        out_first_backup_file_or_dir = get_custom_backup_file_or_dir();
+        backup_dirname = get_custom_backup_dir();
     }
-    if (out_first_backup_file_or_dir.empty()) {
-        out_first_backup_file_or_dir = Glib::build_filename(Glib::path_get_dirname(file_or_dir_path),
-            CtConst::CHAR_DOT + Glib::path_get_basename(file_or_dir_path) + CtConst::CHAR_TILDE);
+    if (backup_dirname.empty()) {
+        backup_dirname = Glib::path_get_dirname(file_or_dir_path);
+    }
+#if defined(_SNAP_BUILD)
+    if (fs_canonicalize_filename(backup_dirname) == fs_canonicalize_filename(Glib::getenv("SNAP_REAL_HOME"))) {
+        out_first_backup_file_or_dir =
+            Glib::build_filename(backup_dirname, CtConst::CHAR_USCORE + Glib::path_get_basename(file_or_dir_path) + CtConst::CHAR_TILDE);
+    }
+    else
+#endif /*_SNAP_BUILD*/
+    {
+        out_first_backup_file_or_dir =
+            Glib::build_filename(backup_dirname, CtConst::CHAR_DOT + Glib::path_get_basename(file_or_dir_path) + CtConst::CHAR_TILDE);
     }
 }
 
@@ -298,13 +308,9 @@ bool CtStorageControl::try_reopen(Glib::ustring& error)
     }
 }
 
-bool CtStorageControl::save(bool need_vacuum, Glib::ustring &error)
+bool CtStorageControl::save(bool need_vacuum, Glib::ustring& error)
 {
     _mod_time = 0;
-    auto on_scope_exit = scope_guard([&](void*) {
-        _pCtMainWin->get_status_bar().pop();
-        _mod_time = fs::getmtime(_file_path);
-    });
     _pCtMainWin->get_status_bar().push(_("Writing to Disk..."));
     while (gtk_events_pending()) gtk_main_iteration();
 
@@ -320,6 +326,14 @@ bool CtStorageControl::save(bool need_vacuum, Glib::ustring &error)
     // CtDocType::MultiFile backups are elsewhere, at node (folder) level rather than whole tree level (file)
     const bool need_main_backup = CtDocType::MultiFile != doc_type and _pCtConfig->backupCopy and _pCtConfig->backupNum > 0;
     const bool need_encrypt = _file_path != _extracted_file_path;
+
+    auto on_scope_exit = scope_guard([this, need_encrypt](void*) {
+        _pCtMainWin->get_status_bar().pop();
+        if (not need_encrypt) {
+            _mod_time = fs::getmtime(_file_path);
+        }
+    });
+
     try {
         if (_file_path.empty()) {
             throw std::runtime_error("storage not initialized");
@@ -363,7 +377,7 @@ bool CtStorageControl::save(bool need_vacuum, Glib::ustring &error)
             _storage->vacuum();
         }
         if (need_main_backup or need_encrypt) {
-            std::shared_ptr<CtBackupEncryptData> pBackupEncryptData = std::make_shared<CtBackupEncryptData>();
+            auto pBackupEncryptData = std::make_shared<CtBackupEncryptData>();
             pBackupEncryptData->backupType = need_main_backup ? CtBackupType::SingleFile : CtBackupType::None;
             pBackupEncryptData->needEncrypt = need_encrypt;
             pBackupEncryptData->file_path = _file_path.string();
@@ -380,6 +394,7 @@ bool CtStorageControl::save(bool need_vacuum, Glib::ustring &error)
                 _storage->reopen_connect();
                 pBackupEncryptData->password = _password;
             }
+            pBackupEncryptData->p_mod_time = &_mod_time;
             backupEncryptDEQueue.push_back(pBackupEncryptData);
         }
         _syncPending.fix_db_tables = false;
@@ -409,12 +424,21 @@ Glib::RefPtr<Gtk::TextBuffer> CtStorageControl::get_delayed_text_buffer(const gi
                                                                         std::list<CtAnchoredWidget*>& widgets) const
 {
     if (not _storage) {
-        spdlog::error("!! storage is not initialized");
+        spdlog::error("!! {} storage is not initialized", __FUNCTION__);
         return Glib::RefPtr<Gtk::TextBuffer>{};
     }
     return _storage->get_delayed_text_buffer(node_id, syntax, widgets);
 }
 
+fs::path CtStorageControl::get_embedded_filepath(const CtTreeIter& ct_tree_iter, const std::string& filename) const
+{
+    if (not _storage) {
+        spdlog::error("!! {} storage is not initialized", __FUNCTION__);
+        return "";
+    }
+    return _storage->get_embedded_filepath(ct_tree_iter, filename);
+}
+
 /*static*/fs::path CtStorageControl::_extract_file(CtMainWin* pCtMainWin, const fs::path& file_path, Glib::ustring& password)
 {
     fs::path temp_dir = pCtMainWin->get_ct_tmp()->getHiddenDirPath(file_path);
@@ -531,14 +555,21 @@ void CtStorageControl::_backupEncryptThread()
             }
             if (not retValEncrypt) {
                 // move back the latest file version
-                (void)fs::move_file(pBackupEncryptData->main_backup, pBackupEncryptData->file_path);
+                if (fs::move_file(pBackupEncryptData->main_backup, pBackupEncryptData->file_path)) {
+                    if (pBackupEncryptData->p_mod_time) {
+                        *pBackupEncryptData->p_mod_time = fs::getmtime(pBackupEncryptData->file_path);
+                    }
 #if defined(DEBUG_BACKUP_ENCRYPT)
-                spdlog::debug("{} -> {}", pBackupEncryptData->main_backup, pBackupEncryptData->file_path.string());
+                    spdlog::debug("{} -> {}", pBackupEncryptData->main_backup, pBackupEncryptData->file_path.string());
 #endif // DEBUG_BACKUP_ENCRYPT
+                }
                 _pCtMainWin->errorsDEQueue.push_back(_("Failed to encrypt the file"));
                 _pCtMainWin->dispatcherErrorMsg.emit();
                 continue;
             }
+            if (pBackupEncryptData->p_mod_time) {
+                *pBackupEncryptData->p_mod_time = fs::getmtime(pBackupEncryptData->file_path);
+            }
 #if defined(DEBUG_BACKUP_ENCRYPT)
             spdlog::debug("{} => {}", pBackupEncryptData->extracted_copy, pBackupEncryptData->file_path.string());
 #endif // DEBUG_BACKUP_ENCRYPT
