@@ -1,7 +1,7 @@
 /*
  * ct_text_view.cc
  *
- * Copyright 2009-2024
+ * Copyright 2009-2025
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -686,10 +686,18 @@ void CtTextView::cursor_and_tooltips_handler(int x, int y)
                 if (i == 1) iter_anchor.backward_char();
                 std::list<CtAnchoredWidget*> widgets = ct_tree_iter.get_anchored_widgets(iter_anchor.get_offset(), iter_anchor.get_offset());
                 if (not widgets.empty()) {
-                    if (CtImagePng* image = dynamic_cast<CtImagePng*>(widgets.front())) {
-                        if (not image->get_link().empty()) {
+                    const CtAnchoredWidget* pCtAnchoredWidget = widgets.front();
+                    if (auto pImage = dynamic_cast<const CtImagePng*>(pCtAnchoredWidget)) {
+                        if (not pImage->get_link().empty()) {
                             hovering_link_iter_offset = text_iter.get_offset();
-                            tooltip = _pCtMainWin->sourceview_hovering_link_get_tooltip(image->get_link());
+                            tooltip = _pCtMainWin->sourceview_hovering_link_get_tooltip(pImage->get_link());
+                            break;
+                        }
+                    }
+                    else if (auto pImage = dynamic_cast<const CtImageAnchor*>(pCtAnchoredWidget)) {
+                        if (0 != CtStrUtil::is_header_anchor_name(pImage->get_anchor_name())) {
+                            hovering_link_iter_offset = text_iter.get_offset();
+                            tooltip = pImage->get_anchor_name();
                             break;
                         }
                     }
@@ -951,7 +959,7 @@ bool CtTextView::_apply_tag_try_link(Gtk::TextIter iter_end, int offset_cursor)
         if (_pCtConfig->urlAutoLink and num_chars > 4 and CtTextIterUtil::startswith_any(iter_start, CtConst::WEB_LINK_STARTERS)) {
             get_buffer()->select_range(iter_start, iter_end);
             Glib::ustring link_url = get_buffer()->get_text(iter_start, iter_end);
-            if (not str::startswith(link_url, "htt") and not str::startswith(link_url, "ftp") and not str::startswith_url(link_url.c_str())) {
+            if (not str::startswith_url(link_url.c_str())) {
                 link_url = "http://" + link_url;
             }
             Glib::ustring property_value = CtConst::LINK_TYPE_WEBS + CtConst::CHAR_SPACE + link_url;
